<?php
namespace VAKS\Common\Page;

use VAKS\AdvancedSettings\Page\AdvancedSettingsPage;
use VAKS\GameFinder\Page\GameFinderPage;
use VAKS\ListManager\Page\ListManagerPage;
use VAKS\PostScanner\Page\PostScanner;
use VAKS\ShortcodeGenerator\Page\ShortcodeGeneratorPage;
use VAKS\ThemeManager\Page\ThemeManagerPage;

class WidgetAdminPage
{
    public static function bind()
    {
        add_action("admin_menu", function () {
            add_submenu_page(
                "tools.php",
                __("Allkeyshop Widget", "allkeyshop-widget"),
                __("Allkeyshop Widget", "allkeyshop-widget"),
                "edit_posts",
                "allkeyshop_widget",
                [self::class, "routeAndRender"]
            );
        });
    }

    public static function routeAndRender()
    {
        wp_enqueue_style("vaks-admin", VAKS_ROOT_URL ."Common/Assets/css/admin.css");

        $subpages = [
            "home" => [
                "class" => "VAKS\\Home\\Page\\HomePage",
                "capability" => "edit_posts",
            ],
            "shortcode_generator" => [
                "class" => ShortcodeGeneratorPage::class,
                "capability" => "edit_posts",
            ],
            "theme_manager" => [
                "class" => ThemeManagerPage::class,
                "capability" => "edit_posts",
            ],
            "game_finder" => [
                "class" => GameFinderPage::class,
                "capability" => "edit_posts",
            ],
            "post_scanner" => [
                "class" => PostScanner::class,
                "capability" => "edit_posts",
            ],
            "advanced_settings" => [
                "class" => AdvancedSettingsPage::class,
                "capability" => "manage_options",
            ],
            "list_manager" => [
                "class" => ListManagerPage::class,
                "capability" => "edit_posts",
            ],
        ];

        $currentSubpageName = (empty($_GET["subpage"]) || !isset($subpages[$_GET["subpage"]]))
            ? "home"
            : $_GET["subpage"];

        $currentSubpage = $subpages[$currentSubpageName];

        if (current_user_can($currentSubpage["capability"]))
        {
            (new $currentSubpage["class"])->render([
                "currentSubpageName" => $currentSubpageName,
            ]);
        }
        else
        {
            // This variable is used in the template
            $data = (object)[
                "currentSubpageName" => $currentSubpageName,
            ];
            require __DIR__."/template/forbidden_page.php";
        }
    }
}
