<?php
namespace VAKS\Common\Shortcode;
use VAKS\Common\Utility\CaseConverter;
use VAKS\Common\Utility\ObjectUtility;
use VAKS\Common\Utility\ParameterManager;
use VAKS\Common\Utility\PresetManager;
use VAKS\Common\Utility\ThemeManager;
use VAKS\Common\Utility\WidgetAssetManager;
use VAKS\VAKS;

class VAKSShortcode
{
    const SHORTCODE_WIDGET = "aks_widget";
    const FILTER_SHORTCODE_CONFIG = "aks_widget_shortcode_config";
    const FILTER_SHORTCODE_TARGET = "aks_widget_shortcode_target";

    public static $instanceCount = 0;

    public static function bind()
    {
        add_shortcode(self::SHORTCODE_WIDGET, [self::class, "preExecute"]);
        add_shortcode("allkeyshop_widget", [self::class, "preExecute"]);
    }

    public static function preExecute($atts = [])
    {
        // Wordpress may pass an empty string
        if (!is_array($atts))
            $atts = [];

        // We use camelCase whereas snake_case is used for the shortcode attributes
        $atts = self::convertAttributeKeysCase($atts);
        $output = self::execute($atts);

        return $output;
    }

    public static function execute(array $atts)
    {
        $atts = self::prepareWidgetContext($atts);
        $output = self::renderWidget($atts);

        return $output;
    }

    public static function prepareWidgetContext($atts)
    {
        $defaults = ParameterManager::getDefaultValues();

        self::handlePreset($atts, $defaults);

        $atts = shortcode_atts($defaults, $atts);

        self::handleTheme($atts);

        if (!isset($atts["id"]))
            $atts["id"] = self::$instanceCount++;

        $atts["target"] = self::filterTarget($atts);

        $atts = apply_filters(self::FILTER_SHORTCODE_CONFIG, $atts);

        return $atts;
    }

    public static function renderWidget(array $atts)
    {
        // Used in the template - do not remove
        $widget = ObjectUtility::toObject($atts);

        ob_start();
        require VAKS_ROOT_DIR . "Common/template/widget.php";
        $output = ob_get_contents();
        ob_end_clean();

        WidgetAssetManager::enqueueAssets($atts);

        return $output;
    }

    private static function filterTarget(array $atts)
    {
        $target = (isset($atts["target"]))
            ? $atts["target"]
            : null;

        $target = apply_filters(self::FILTER_SHORTCODE_TARGET, $target, $atts);

        return $target;
    }

    private static function handlePreset(array &$atts, array &$defaults)
    {
        $presetName = (!empty($atts["preset"]))
            ? $atts["preset"]
            : VAKS::instance()->config->get("defaultPresetName");

        $preset = PresetManager::getPreset($presetName);

        if ($preset)
            $defaults = shortcode_atts($defaults, $preset);

        unset($atts["preset"]);
    }

    private static function handleTheme(array &$atts)
    {
        if (!empty($atts["theme"]))
        {
            // A custom CSS overrides the theme
            if (empty($atts["css"]))
                $atts["css"] = ThemeManager::getThemeUrl($atts["theme"]);

            unset($atts["theme"]);
        }
    }

    private static function convertAttributeKeysCase(array $atts)
    {
        $output = array();

        foreach ($atts as $key => $value)
        {
            $newKey = CaseConverter::snakeToCamel($key);
            $output[$newKey] = $value;
        }

        return $output;
    }
}
