<?php
namespace VAKS\Common\Utility;

use VAKS\Common\Shortcode\VAKSShortcode;
use VAKS\VAKS;

class PostWidgetUtility
{
    public static function getWidgetShortcodeForPost($postId)
    {
        $atts = self::getWidgetAttsForPost($postId);

        return self::convertAttsToShortcode($atts);
    }

    public static function getWidgetAttsForPost($postId)
    {
        $gameIds = self::getGameIds($postId);
        $atts = self::getPresetAtts($postId);
        $atts["target"] = $gameIds;

        return $atts;
    }

    private static function convertAttsToShortcode(array $atts)
    {
        $shortcode = "[". VAKSShortcode::SHORTCODE_WIDGET;

        foreach ($atts as $key => $value)
            $shortcode .= " ". $key ."=". json_encode($value);

        $shortcode .= "]";

        return $shortcode;
    }

    public static function getGameIds($postId)
    {
        $games = get_post_meta($postId, VAKS::instance()->config->get("metaKeys.games"), true);

        if (!$games || count($games) === 0)
            return "";

        $gameIds = implode(",", array_column($games, "id"));

        return $gameIds;
    }

    private static function getPresetAtts($postId)
    {
        $presetName = get_post_meta($postId, VAKS::instance()->config->get("metaKeys.preset"), true);
        $atts = array();

        if ($presetName)
        {
            $preset = PresetManager::getPreset($presetName);

            if ($preset)
                $atts = $preset;
        }

        return $atts;
    }
}