<?php
namespace VAKS\Common\Widget;
use VAKS\Common\Shortcode\VAKSShortcode;
use VAKS\Common\Utility\ObjectUtility;
use VAKS\Common\Utility\ParameterManager;
use VAKS\Common\Utility\PresetManager;
use VAKS\Common\Utility\WidgetAssetManager;
use VAKS\Common\Utility\WidgetFormData;
use VAKS\VAKS;

class VAKSWidget extends \WP_Widget
{
    public static function bind()
    {
        add_action("widgets_init", function () {
            register_widget(self::class);
        });

        add_action("admin_enqueue_scripts", [self::class, "enqueueAssets"]);
    }


    public function __construct()
    {
        $options = [
            "description" => __("Allkeyshop Widget integration for WordPress", "allkeyshop-widget"),
        ];

        parent::__construct("vaks_widget", __("Allkeyshop Widget", "allkeyshop-widget"), $options);
    }

    public static function enqueueAssets()
    {
        $screen = get_current_screen();

        if (is_object($screen) && $screen->id === "widgets")
        {
            wp_enqueue_script("vaks-widget-form", VAKS_ROOT_URL ."Common/Assets/js/WidgetForm.js");
            wp_enqueue_script("vaks-wp-widget-loader", VAKS_ROOT_URL ."Common/Assets/js/WPWidgetLoader.js");
            wp_enqueue_style("vaks-admin", VAKS_ROOT_URL ."Common/Assets/css/admin.css");
        }
    }

    public function widget($args, $instance)
    {
        echo VAKSShortcode::execute($instance);
    }

    public function form($instance)
    {
        $defaults = ParameterManager::getDefaultValues();
        $presetName = VAKS::instance()->config->get("defaultPresetName");
        $preset = PresetManager::getPreset($presetName);

        if ($preset)
            $defaults = shortcode_atts($defaults, $preset);

        $instance = wp_parse_args($instance, $defaults);
        $data = WidgetFormData::getFormData(
            function ($fieldName) use ($instance) {
                return (isset($instance[$fieldName]))
                    ? $instance[$fieldName]
                    : null;
            },
            function ($fieldName) {
                return $this->get_field_name($fieldName);
            },
            function ($fieldName) {
                return $this->get_field_id($fieldName);
            }
        );

        // Used in the template - do not remove
        $data = ObjectUtility::toObject($data);
        $data->instantiateWidgetForm = true;

        require VAKS_ROOT_DIR . "/Common/template/widget_form.php";
    }

    public function update($newInstance, $oldInstance)
    {
        $instance = [];
        $defaults = ParameterManager::getDefaultValues();
        $defaults = ObjectUtility::toObject($defaults);
        $config = VAKS::instance()->config;
        $locales = $config->get("locales");
        $currencies = $config->get("currencies");

        $instance["target"] = (isset($newInstance["target"]))
            ? $newInstance["target"]
            : $defaults->target;

        $instance["width"] = (isset($newInstance["width"]))
            ? $newInstance["width"]
            : $defaults->width;

        $instance["height"] = (isset($newInstance["height"]))
            ? $newInstance["height"]
            : $defaults->height;

        $instance["locale"] = (isset($newInstance["locale"]) && in_array($newInstance["locale"], $locales))
            ? $newInstance["locale"]
            : $defaults->locale;

        $instance["currency"] = (isset($newInstance["currency"]) && in_array($newInstance["currency"], $currencies))
            ? $newInstance["currency"]
            : $defaults->currency;

        $instance["defaultTab"] = (isset($newInstance["defaultTab"]))
            ? $newInstance["defaultTab"]
            : $defaults->defaultTab;

        $instance["customPageUrl"] = (isset($newInstance["customPageUrl"]) && filter_var($newInstance["customPageUrl"], FILTER_VALIDATE_URL))
            ? $newInstance["customPageUrl"]
            : $defaults->customPageUrl;

        $instance["customPageTitle"] = (isset($newInstance["customPageTitle"]))
            ? $newInstance["customPageTitle"]
            : $defaults->customPageTitle;

        $instance["showVouchers"] = (isset($newInstance["showVouchers"]))
            ? !!$newInstance["showVouchers"]
            : false;

        $instance["theme"] = (isset($newInstance["theme"]))
            ? $newInstance["theme"]
            : $defaults->theme;

        $instance["showGameCard"] = (isset($newInstance["showGameCard"]))
            ? !!$newInstance["showGameCard"]
            : false;


        $tabs = VAKS::instance()->config->get("tabs");
        $tabString = "";

        foreach ($newInstance as $key => $value)
        {
            if (strpos($key, "tab") === 0)
            {
                $tabName = lcfirst(substr($key, 3));

                if (isset($tabs->{$tabName}))
                    $tabString .= "$tabName,";
            }
        }

        $instance["tabs"] = rtrim($tabString, ",");


        $excludableOfferFields = VAKS::instance()->config->get("offerExcludableFields");
        $offerExcludedFieldsString = "";

        foreach ($newInstance as $key => $value)
        {
            if (strpos($key, "offerExcludedField") === 0)
            {
                $fieldName = lcfirst(substr($key, 18));

                if (isset($excludableOfferFields->{$fieldName}))
                    $offerExcludedFieldsString .= "$fieldName,";
            }
        }

        $instance["offerExcludedFields"] = rtrim($offerExcludedFieldsString, ",");

        return $instance;
    }
}
