<?php
namespace VAKS\Common\WordPress;
use VAKS\Common\Shortcode\VAKSShortcode;
use VAKS\Common\Utility\PresetManager;
use VAKS\VAKS;

class InjectWidgetIntoPost
{
    public static function bind()
    {
        add_filter("the_content", [self::class, "execute"]);
    }

    public static function execute($content)
    {
        global $post;

        $mode = get_post_meta($post->ID, VAKS::instance()->config->get("metaKeys.mode", "hidden"), true);

        if (!$mode || $mode === "hidden")
            return $content;

        $position = get_post_meta($post->ID, VAKS::instance()->config->get("metaKeys.position"), true);

        if ($position === "none")
            return $content;

        $shortcode = self::getWidgetShortcodeForPost($post->ID);

        switch ($position)
        {
            case "before":
                return $shortcode . $content;
            case "after":
            default:
                return $content . $shortcode;
        }
    }

    public static function getWidgetShortcodeForPost($postId)
    {
        $gameIds = self::getGameIds($postId);
        $atts = self::getPresetAtts($postId);
        $atts["target"] = $gameIds;

        return self::convertAttsToShortcode($atts);
    }

    private static function convertAttsToShortcode(array $atts)
    {
        $shortcode = "[". VAKSShortcode::SHORTCODE_WIDGET;

        foreach ($atts as $key => $value)
            $shortcode .= " ". $key ."=". json_encode($value);

        $shortcode .= "]";

        return $shortcode;
    }

    private static function getGameIds($postId)
    {
        $games = get_post_meta($postId, VAKS::instance()->config->get("metaKeys.games"), true);

        if (!$games || count($games) === 0)
            return "";

        $gameIds = implode(",", array_column($games, "id"));

        return $gameIds;
    }

    private static function getPresetAtts($postId)
    {
        $presetName = get_post_meta($postId, VAKS::instance()->config->get("metaKeys.preset"), true);
        $atts = [];

        if ($presetName)
        {
            $preset = PresetManager::getPreset($presetName);

            if ($preset)
                $atts = $preset;
        }

        return $atts;
    }
}