<?php
namespace VAKS\Common\WordPress;
use VAKS\Common\AdminNotice\AdminNotice;
use VAKS\Common\Utility\PresetManager;
use VAKS\PostScanner\Utility\GameExtractor;
use VAKS\Common\Utility\VAKSAPI;
use VAKS\VAKS;

class OnPostSave
{
    public static function bind()
    {
        add_action("save_post", [self::class, "savePost"]);
    }

    public static function savePost($postId)
    {
        $post = get_post($postId);

        if (!$post)
            return ;

        $mode = self::saveMode($post);
        self::savePosition($post);
        self::savePreset($post);

        if ($mode === "auto")
        {
            $gameIds = self::guessGameIds($post);

            if (count($gameIds) > 0)
                add_filter("redirect_post_location", [self::class, "addSuccessQueryVar"], 99);
            else
                add_filter("redirect_post_location", [self::class, "addErrorQueryVar"], 99);
        }
        else if ($mode === "manual" && !empty($_POST["vaks_widget"]["game_ids"]))
            $gameIds = $_POST["vaks_widget"]["game_ids"];
        else
            $gameIds = [];

        $config = VAKS::instance()->config;
        $gamesMeta = $config->get("metaKeys.games");

        if (count($gameIds) > 0)
            update_post_meta($post->ID, $gamesMeta, self::getGamesData($gameIds));
        else
            delete_post_meta($post->ID, $gamesMeta);
    }

    private static function saveMode($post)
    {
        $modes = ["auto", "manual", "hidden"];

        if (isset($_POST["vaks_widget"]) && in_array($_POST["vaks_widget"]["mode"], $modes))
        {
            $mode = $_POST["vaks_widget"]["mode"];
            $config = VAKS::instance()->config;
            update_post_meta($post->ID, $config->get("metaKeys.mode"), $mode);

            return $mode;
        }

        return null;
    }

    private static function savePosition($post)
    {
        $positions = ["before", "after", "none"];
        $metaKey = VAKS::instance()->config->get("metaKeys.position");

        if (isset($_POST["vaks_widget"]["position"]) && in_array($_POST["vaks_widget"]["position"], $positions))
        {
            $position = $_POST["vaks_widget"]["position"];
            update_post_meta($post->ID, $metaKey, $position);

            return $position;
        }
        else
            delete_post_meta($post->ID, $metaKey);

        return null;
    }

    private static function savePreset($post)
    {
        $presets = array_keys(PresetManager::getPresets());
        $metaKey = VAKS::instance()->config->get("metaKeys.preset");

        if (isset($_POST["vaks_widget"]["preset"]) && in_array($_POST["vaks_widget"]["preset"], $presets))
        {
            $preset = $_POST["vaks_widget"]["preset"];
            update_post_meta($post->ID, $metaKey, $preset);

            return $preset;
        }
        else
            delete_post_meta($post->ID, $metaKey);

        return null;
    }

    private static function guessGameIds($post)
    {
        $suggestions = GameExtractor::getGamesFromPost($post);

        return (count($suggestions) > 0)
            ? [$suggestions[0]["id"]]
            : [];
    }

    private static function getGamesData(array $gameIds)
    {
        $games = (new VAKSAPI)->getGames($gameIds);
        $output = [];

        foreach ($games as $game)
        {
            $output[$game->id] = [
                "id" => $game->id,
                "name" => $game->name,
            ];
        }

        return $output;
    }

    public static function addErrorQueryVar($location)
    {
        remove_filter("redirect_post_location", self::class ."::addErrorQueryVar", 99);
        return add_query_arg([AdminNotice::PREFIX ."auto_detection_error" => 1], $location);
    }

    public static function addSuccessQueryVar($location)
    {
        remove_filter("redirect_post_location", self::class ."::addSuccessQueryVar", 99);
        return add_query_arg([AdminNotice::PREFIX ."auto_detection_success" => 1], $location);
    }
}