<?php

$renderDescription = function ($description)
{
    if ($description)
    {
        ?>
        <span class="vaks-widget-form-description"><?php echo $description ?></span>
        <?php
    }
};

$renderSelect = function ($field, $values, $label, $description = "", $blankLineName = null) use ($renderDescription)
{
    ?>
    <p>
        <label for="<?php echo $field->id ?>"><?php echo $label ?></label>
        <select
            id="<?php echo $field->id ?>"
            name="<?php echo $field->name ?>"
            data-vaks-param="<?php echo $field->key ?>"
            class="widefat"
        >
            <?php
            if ($blankLineName)
            {
                ?>
                <option
                    value=""
                    <?php echo (!$field->value) ? "selected" : "" ?>
                >
                    <?php echo $blankLineName ?>
                </option>
                <?php
            }

            foreach ($values as $value)
            {
                ?>
                <option
                    value="<?php echo $value ?>"
                    <?php echo ($field->value === $value) ? "selected" : "" ?>
                >
                    <?php echo $value ?>
                </option>
                <?php
            }
            ?>
        </select>
    </p>

    <?php
    $renderDescription($description);
};

$renderTextField = function ($field, $label, $placeholder = "", $description = "") use ($renderDescription)
{
    ?>
    <p>
        <label for="<?php echo $field->id ?>"><?php echo $label ?></label>
        <input
            id="<?php echo $field->id ?>"
            name="<?php echo $field->name ?>"
            value="<?php echo $field->value ?>"
            data-vaks-param="<?php echo $field->key ?>"
            type="text"
            placeholder="<?php echo $placeholder ?>"
            class="widefat"
        >
    </p>

    <?php
    $renderDescription($description);
};

$renderCheckbox = function ($field, $label, $description = "") use ($renderDescription)
{
    ?>
    <p>
        <span style="display: flex">
            <span>
                <input
                    type="checkbox"
                    id="<?php echo $field->id ?>"
                    name="<?php echo $field->name ?>"
                    data-vaks-param="<?php echo $field->key ?>"
                    <?php echo $field->value ? "checked" : "" ?>
                >
            </span>
            <span>
                <label for="<?php echo $field->id ?>"><?php echo $label ?></label>
                <?php $renderDescription($description); ?>
            </span>
        </span>
    </p>
    <?php
};

$renderList = function ($form, $values, $selection, $fieldPrefix, $label) use ($renderDescription)
{
    ?>
    <p>
        <?php echo $label ?><br>
        <span class="vaks-widget-form-list">
            <?php
            foreach ($values as $key => $value)
            {
                $field = $fieldPrefix . ucfirst($key);
                ?>
                <input
                    type="checkbox"
                    id="<?php echo $form->{$field}->id ?>"
                    name="<?php echo $form->{$field}->name ?>"
                    data-vaks-param="<?php echo $form->{$field}->key ?>"
                    <?php echo in_array($key, $selection) ? "checked" : "" ?>
                >
                <label for="<?php echo $form->{$field}->id ?>"><?php _e($value->name, "allkeyshop-widget") ?></label>
                <br>
                <?php
            }
            ?>
        </span>
    </p>
    <?php
};

?>
<div class="text-widget-fields">
    <h4 class="vaks-widget-form-section-title"><?php _e("General settings", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php $renderSelect($data->form->locale, $data->availableLocales, __("Locale", "allkeyshop-widget")) ?>
        <?php $renderSelect($data->form->currency, $data->availableCurrencies, __("Currency", "allkeyshop-widget")) ?>
        <?php $renderTextField($data->form->target, __("Target", "allkeyshop-widget"), "", __("Must be one or several game IDs separated with a comma or a list slug.", "allkeyshop-widget")) ?>
    </div>

    <h4 class="vaks-widget-form-section-title"><?php _e("Appearance", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php $renderSelect($data->form->theme, $data->availableThemes, __("Theme", "allkeyshop-widget"), "", "Default") ?>
        <div data-vaks-css>
            <?php $renderTextField($data->form->css, __("Custom CSS", "allkeyshop-widget"),"", __("Must be a URL", "allkeyshop-widget")) ?>
        </div>
        <?php $renderTextField($data->form->width, __("Width", "allkeyshop-widget"),"", __("Must be a number with a HTML unit (%, px, ...).", "allkeyshop-widget")) ?>
        <?php $renderTextField($data->form->height, __("Height", "allkeyshop-widget"),"", __("Must be a number with a HTML unit (%, px, ...).", "allkeyshop-widget")) ?>
        <?php $renderCheckbox($data->form->autoHeight, __("Ajust height automatically", "allkeyshop-widget"), __("Automatically adapt the widget height to the game list (otherwise, the 'height' parameter above is used).<br>If the 'height' parameter is left empty, there will be no height limit.", "allkeyshop-widget")) ?>
    </div>

    <h4 class="vaks-widget-form-section-title"><?php _e("Tabs", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php
        $currentlySelectedTabs = explode(",", $data->form->tabs->value);
        $renderList($data->form, $data->availableTabs, $currentlySelectedTabs, "tab", __("Visible tabs:", "allkeyshop-widget"));
        ?>

        <p>
            <label for="<?php echo $data->form->defaultTab->id ?>"><?php _e("Default Tab", "allkeyshop-widget") ?></label>
            <select
                id="<?php echo $data->form->defaultTab->id ?>"
                name="<?php echo $data->form->defaultTab->name ?>"
                data-vaks-param="<?php echo $data->form->defaultTab->key ?>"
                class="widefat"
            >
                <?php
                foreach ($data->availableTabs as $tabName => $tab)
                {
                    if (!$tab->selectable)
                        continue ;
                    ?>
                    <option
                        value="<?php echo $tabName ?>"
                        <?php echo ($data->form->defaultTab->value === $tabName) ? "selected" : "" ?>
                    >
                        <?php _e($tab->name, "allkeyshop-widget") ?>
                    </option>
                    <?php
                }
                ?>
            </select>
        </p>
    </div>


    <div data-vaks-custom-page-tab-section>
        <h4 class="vaks-widget-form-section-title"><?php _e("Custom page tab", "allkeyshop-widget") ?></h4>

        <div class="vaks-widget-form-section">
            <?php $renderTextField($data->form->customPageUrl, __("Custom Page URL", "allkeyshop-widget"), "https://") ?>
            <?php $renderTextField($data->form->customPageTitle, __("Custom Page Title", "allkeyshop-widget"), "", __("Leaving this blank will hide the custom page tab.", "allkeyshop-widget")) ?>
        </div>
    </div>


    <h4 class="vaks-widget-form-section-title"><?php _e("Offers", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php $renderTextField($data->form->offersPerPage, __("Offers per page", "allkeyshop-widget"), "", __("Set to -1 to disable pagination.", "allkeyshop-widget")) ?>

        <?php $renderTextField($data->form->regions, __("Regions IDs", "allkeyshop-widget"), "", __("Must be comma-separated IDs.", "allkeyshop-widget")) ?>
        <?php $renderSelect($data->form->regionsMode, $data->regionsModes, __("Regions mode", "allkeyshop-widget")) ?>

        <?php $renderTextField($data->form->editions, __("Editions IDs", "allkeyshop-widget"), "", __("Must be comma-separated IDs.", "allkeyshop-widget")) ?>
        <?php $renderSelect($data->form->editionsMode, $data->editionsModes, __("Editions mode", "allkeyshop-widget")) ?>
    </div>


    <h4 class="vaks-widget-form-section-title"><?php _e("Price list", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php
        $offerExcludedFields = explode(",", $data->form->offerExcludedFields->value);
        $renderList($data->form, $data->offerExcludableFields, $offerExcludedFields, "offerExcludedField", __("Hide columns:", "allkeyshop-widget"))
        ?>

        <?php $renderCheckbox($data->form->showVouchers, __("Show voucher codes", "allkeyshop-widget")) ?>
    </div>


    <h4 class="vaks-widget-form-section-title"><?php _e("Game list", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php $renderCheckbox($data->form->showOfficialPrice, __("Show official prices on the game list", "allkeyshop-widget")) ?>
        <?php $renderCheckbox($data->form->openAksOnClick, __("Open the AllKeyShop game page when the user clicks on the game", "allkeyshop-widget")) ?>

        <div style="margin-left: 15px">
            <?php $renderCheckbox($data->form->openAksInNewTab, __("Open the AllKeyShop page in a new tab", "allkeyshop-widget")) ?>
        </div>
    </div>


    <h4 class="vaks-widget-form-section-title"><?php _e("Other", "allkeyshop-widget") ?></h4>

    <div class="vaks-widget-form-section">
        <?php $renderCheckbox($data->form->showPlatforms, __("Show the platform selector", "allkeyshop-widget")) ?>
        <?php $renderCheckbox($data->form->showGameCard, __("Show the game card", "allkeyshop-widget")) ?>
        <?php $renderCheckbox($data->form->hideWhenNoData, __("Hide the widget when there is no results", "allkeyshop-widget")) ?>
        <?php $renderTextField($data->form->gameNameTabUrl, __("Game name tab URL", "allkeyshop-widget"), "", __("Leave blank to use Allkeyshop links", "allkeyshop-widget")) ?>
    </div>
</div>

<?php if (isset($data->instantiateWidgetForm) && $data->instantiateWidgetForm) { ?>
    <script>
        new VAKS.WidgetForm(jQuery(document.currentScript).closest("form"));
    </script>
<?php }
