jQuery(document).ready(function ($) {
    var $form = $("#gameFinderForm");
    var $resultTable = $("#gameFinderResults");
    var currentQuery = null;
    var prevKeywords = $form[0].elements.keywords.value;
    var prevCurrency = $form[0].elements.currency.value;
    var keywordsMinLength = 3;
    var timer = null;

    function findGames()
    {
        var keywords = $form[0].elements.keywords.value;
        var currency = $form[0].elements.currency.value;

        if (keywords === prevKeywords && currency === prevCurrency)
            return ;

        prevKeywords = keywords;
        prevCurrency = currency;

        if (keywords.length < keywordsMinLength)
            return showError(vaksTrans.keywordsTooShort.replace("__LENGTH__", keywordsMinLength));

        if (currentQuery)
            currentQuery.abort();

        showLoading();

        currentQuery = $.get({
            url: vaksTrans.apiUrl +"vaks.php",
            data: {
                action: "products",
                currency: currency,
                search: keywords,
            },
            dataType: "json",
            success: function (data)
            {
                updateResultTable(data.products);
            },
            error: function (response) {
                if (response.statusText === "abort")
                    return ;

                showError(vaksTrans.unexpectedError);

                if (response.responseJSON && response.responseJSON.errors)
                    console.error("Allkeyshop Widget Error: "+ response.responseJSON.errors.join(" | "));
            },
            complete: function (response) {
                currentQuery = null;
            }
        });
    }

    function updateResultTable(results)
    {
        $resultTable.empty();

        if (results.length === 0)
        {
            $resultTable
                .empty()
                .append('<tr><td colspan="2" style="text-align: center">'+ vaksTrans.noResults +'</td></tr>');
        }
        else
        {
            results.forEach(function (result) {
                $resultTable.append(buildResultRow(result));
            });
        }
    }

    function buildResultRow(result)
    {
        return "<tr>"+
            "<td>"+ result.id +"</td>"+
            "<td>"+ result.name +"</td>"+
        "</tr>";
    }

    function showError(message)
    {
        $resultTable
            .empty()
            .append('<tr><td colspan="2" class="vaks-error" style="text-align: center">'+ message +'</td></tr>');
    }

    function showLoading()
    {
        $resultTable
            .empty()
            .append('<tr><td colspan="2" style="text-align: center"><div class="lds-dual-ring"></div>');
    }

    function onFormSubmit(e)
    {
        e.preventDefault();
        findGames();
    }

    function onKeyDown()
    {
        if (timer)
            clearInterval(timer);

        // So we don't send a request for each keystoke
        timer = setTimeout(function () {
            timer = null;
            findGames();
        }, 400);
    }

    $form
        .on("keydown", ":input", onKeyDown)
        .submit(onFormSubmit);
});
