<?php
use VAKS\VAKS;

$attrs = [
    [
        "name" => "target",
        "description" => '
Defines the products you want to show in the widget.<br>
It can take several types of values:
',
        "acceptedValues" => [
            [
                "text" => '<b>A product ID:</b> An integer representing the Allkeyshop ID of the product.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="281"]</span>
                    Sets the target to GTA 5 (ID: 281)',
                ],
            ],
            [
                "text" => '<b>A list of IDs:</b> A comma-separated list of Allkeyshop IDs. The widget will display a list of the specified games.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="281,101"]</span>
                    Sets the targets to GTA 5 (ID: 281) and Borderlands (ID: 101)',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="281,"]</span>
                    To make the widget display a list with only one game',
                ],
            ],
            [
                "text" => '<b>A pre-built list slug:</b> The slug of a list built with the <a href="?page=allkeyshop_widget&subpage=list_manager">list manager</a>, with <span class="aks-doc-code">list:</span> as a prefix.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="list:my-list"]</span>
                    Will display the list in the same way than the 2nd element of this list.',
                ],
            ],
            [
                "text" => '<b>A post ID:</b> The ID of a post, with <span class="aks-doc-code">post:</span> as a prefix. The widget will show the games attached to this post. You can give the value <span class="aks-doc-code">auto</span> to select the currently displayed post.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="post:123"]</span>
                    Will fetch the games attached to the post #123',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="post:auto"]</span>
                    Will fetch the games attached to the currently displayed post',
                ],
            ],
            [
                "text" => '<b>An AKS list slug:</b> The slug of an AKS list. Will display a list with all the contained products.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget target="fps"]</span>
                    "fps" is an AKS list containing the top FPS games',
                ],
            ],
        ],
    ],
    [
        "name" => "locale",
        "description" => '
The locale of the widget.
As the widget is still under development, there is only a few locales supported.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">en_GB</span>: english',
            ],
            [
                "text" => '<span class="aks-doc-code">fr_FR</span>: french',
            ],
        ],
    ],
    [
        "name" => "currency",
        "description" => '
The currency of the offers the widget shows.<br>
Some currencies would show offers other currencies don\'t: that\'s because some offers are only available in those currencies.<br>
Available currencies:
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">eur</span>: Euro €',
            ],
            [
                "text" => '<span class="aks-doc-code">usd</span>: US Dollar $',
            ],
        ],
    ],
    [
        "name" => "theme",
        "description" => '
The name of the theme. You can edit themes in the <a href="?page=allkeyshop_widget&subpage=theme_manager">theme manager</a>.
',
    ],
    [
        "name" => "custom_css",
        "description" => '
An URL of a CSS file that will be injected in the widget.
',
    ],
    [
        "name" => "width",
        "description" => '
Sets the width of the widget.
',
        "acceptedValues" => [
            [
                "text" => 'All values the <span class="aks-doc-code">width</span> css property can take',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget width="500px"]</span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget width="50%"]</span>',
                ],
            ],
        ],
    ],
    [
        "name" => "height",
        "description" => '
Sets the height of the widget.
',
        "acceptedValues" => [
            [
                "text" => 'All values the <span class="aks-doc-code">height</span> css property can take.<br>
                            If the <span class="aks-doc-code">auto_height</span> is enabled, this value will define the maximum height of the widget.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget height="500px"]</span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget height="50%"]</span>',
                ],
            ],
        ],
    ],
    [
        "name" => "auto_height",
        "description" => '
Determines if the widget should automatically ajusts its height according to its content\'s height.<br>
If the <span class="aks-doc-code">height</span> attribute, it will define the maximum height. If it is empty, there will be no maximum height.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget auto_height="1"]</span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget auto_height="off"]</span>',
                ],
            ],
        ],
    ],
    [
        "name" => "tabs",
        "description" => '
Determines which tabs to show. If empty, all the tabs will be shown.
',
        "acceptedValues" => [
            [
                "text" => 'A comma-separated list of the tab names. The available tabs are: 
                '. implode(", ", array_keys(VAKS::instance()->config->getAssoc("tabs"))) .'
',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget tabs="offers,reviews"]</span> Only the offers and reviews tabs will be shown',
                ],
            ],
        ],
    ],
    [
        "name" => "default_tab",
        "description" => '
Determines which tabs is shown by default.
',
        "acceptedValues" => [
            [
                "text" => 'The name of the default tab. The available tabs are: 
                '. implode(", ", array_keys(VAKS::instance()->config->getAssoc("tabs"))) .'
',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget tabs="offers,reviews"]</span> Only the offers and reviews tabs will be shown',
                ],
            ],
        ],
    ],
    [
        "name" => "offers_per_page",
        "description" => '
The number of offers shown each time the user presses the "Show more offers" button.
',
        "acceptedValues" => [
            [
                "text" => 'An integer > 0 or -1 to show all offers at once.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget offers_per_page="5"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget offers_per_page="-1"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "regions",
        "description" => '
Sets the list of regions to show or hide (depending on the <span class="aks-doc-code">regions_mode</span> attribute)
',
        "acceptedValues" => [
            [
                "text" => 'A comma-separated list of the regions IDs',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget regions="steamrow,steamapac"]</span> Will only show the Steam ROW and the Steam APAC regions<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "regions",
        "description" => '
If set to <span class="aks-doc-code">include</span>, will only show offers available in the regions set in the <span class="aks-doc-code">regions</span> attribute.<br>
If set to <span class="aks-doc-code">exclude</span>, will show all offers except the ones available in the regions set in the <span class="aks-doc-code">regions</span> attribute.<br>
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">include</span> (default) or <span class="aks-doc-code">exclude</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget regions="steamrow,steamapac" regions_mode="exclude"]</span> Will show all the regions but the Steam ROW and the Steam APAC regions',
                ],
            ],
        ],
    ],
    [
        "name" => "editions",
        "description" => '
Sets the list of editions to show or hide (depending on the <span class="aks-doc-code">editions_mode</span> attribute)
',
        "acceptedValues" => [
            [
                "text" => 'A comma-separated list of the editions IDs',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget editions="1,7"]</span> Will only show the Standard (ID: 1) and Bonus (ID: 7) editions',
                ],
            ],
        ],
    ],
    [
        "name" => "editions",
        "description" => '
If set to <span class="aks-doc-code">include</span>, will only show offers available in the editions set in the <span class="aks-doc-code">editions</span> attribute.<br>
If set to <span class="aks-doc-code">exclude</span>, will show all offers except the ones available in the editions set in the <span class="aks-doc-code">editions</span> attribute.<br>
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">include</span> (default) or <span class="aks-doc-code">exclude</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget editions="steamrow,steamapac" editions_mode="exclude"]</span> Will show all editions but the Standard (ID: 1) and Bonus (ID: 7) editions<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "offer_excluded_fields",
        "description" => '
Determines which field of the offers tab should be hidden.
',
        "acceptedValues" => [
            [
                "text" => 'A comma-separated list of the field names. Available field names: <span class="aks-doc-code">region</span>, <span class="aks-doc-code">edition</span>.',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget offer_excluded_fields="region,edition"]</span> Will hide both the region and edition fields',
                ],
            ],
        ],
    ],
    [
        "name" => "show_vouchers",
        "description" => '
Shows the voucher codes.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_vouchers="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_vouchers="off"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "show_official_price",
        "description" => '
In list mode, shows the official store price.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_official_price="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_official_price="off"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "open_aks_on_click",
        "description" => '
If enabled, a click on the product name in the tab section will open the AKS product page.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget open_aks_on_click="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget open_aks_on_click="off"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "open_aks_in_new_tab",
        "description" => '
If enabled, opens the AKS product page in a new tab.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget open_aks_in_new_tab="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget open_aks_in_new_tab="off"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "show_platforms",
        "description" => '
Shows the list of the available platforms for this product.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_platforms="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_platforms="off"]<span>',
                ],
            ],
        ],
    ],
    [
        "name" => "show_game_card",
        "description" => '
Shows the game card on top of the widget.
',
        "acceptedValues" => [
            [
                "text" => '<span class="aks-doc-code">1</span> / <span class="aks-doc-code">0</span> or <span class="aks-doc-code">on</span> / <span class="aks-doc-code">off</span>',
                "examples" => [
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_game_card="1"]<span>',
                    '<span class="aks-doc-code aks-doc-example-code">[aks_widget show_game_card="off"]<span>',
                ],
            ],
        ],
    ],
];
?>

<style>
    h3 {
        font-size: 16px;
        margin-bottom: -10px;
    }

    .aks-doc-code {
        background-color: #d8d8d8;
        font-family: monospace;
        border-radius: 3px;
        padding: 3px;
    }

    .aks-doc-attributes {
        margin-left: 20px;
    }

    .aks-doc-title {
        margin-bottom: 0;
        font-size: 15px;
        margin-top: 25px;
    }

    .aks-doc-desc {
        margin-top: 5px;
    }

    .aks-doc-values {
        margin-top: 5px;
        margin-left: 25px;
    }

        .aks-doc-values > li::before {
            content: "•";
            float: left;
            margin-right: 4px;
            margin-left: -10px;
        }

            .aks-doc-examples {
                display: flex;
                margin-left: 20px;
                margin-top: 6px;
            }

                .aks-doc-examples-label {
                    margin-right: 30px;
                    color: #797979;
                    font-style: italic;
                }

                .aks-doc-example-code {
                    margin-right: 10px;
                }
</style>

<div class="wrap">
    <div style="width: 800px">
        <h1><?php _e("Allkeyshop Widget", "allkeyshop-widget") ?></h1>

        <?php require VAKS_ROOT_DIR . "/Common/Page/template/tabs.php" ?>

        <h2>Important notice</h2>
        This plugin is still in development, which means everything is subject to change.

        <h2>The WordPress widget</h2>
        <p>You can set up widgets by going in the <a href="<?= admin_url("themes.php") ?>">Apparence</a> > <a href="<?= admin_url("widgets.php") ?>">Widgets</a> menu and drag-and-dropping the <b>Allkeyshop Widget</b> block.</p>

        <h2>The shortcode</h2>
        <p>Using the AKS Widget shortcode (<span class="aks-doc-code">[aks_widget]</span>) is a way to inject the widget into your pages.</p>
        <p>
            Writing widget shortcodes can quickly become a tedious work, as there can be a lot of attributes if you customize each part of the widget. To help you with that, we developed the <a href="?page=allkeyshop-widget&subpage=shortcode_generator">shortcode generator</a>.<br>
            Also, this tool is a good way to see how each attribute affect the widget as you can change them and see the result on the fly.
        </p>

        <h3>Shortcode attributes</h3>

        <div class="aks-doc-attributes">
            <?php foreach ($attrs as $attr) { ?>
                <h4 class="aks-doc-title"><?= $attr["name"] ?></h4>

                <p class="aks-doc-desc"><?= $attr["description"] ?></p>

                <?php if (isset($attr["acceptedValues"])) { ?>
                    <div style="color: #797979;">Accepted values</div>

                    <ul class="aks-doc-values">
                        <?php foreach ($attr["acceptedValues"] as $value) { ?>
                            <li>
                                <?= $value["text"] ?>

                                <?php if (isset($value["examples"])) { ?>
                                    <div class="aks-doc-examples">
                                        <div class="aks-doc-examples-label">
                                            Examples:
                                        </div>

                                        <ul>
                                            <?php foreach ($value["examples"] as $example) { ?>
                                                <li><?= $example ?></li>
                                            <?php } ?>
                                        </ul>
                                    </div>
                                    <div style="margin-top: 10px;"></div>
                                <?php } ?>
                            </li>
                        <?php } ?>
                    </ul>
                <?php } ?>
            <?php } ?>
        </div>
    </div>
</div>
