<?php
namespace VAKS\ListManager\Page;

use VAKS\Common\Utility\ListManager;
use VAKS\Common\Utility\ObjectUtility;
use VAKS\Common\Utility\VAKSAPI;
use VAKS\ListManager\Utility\ListTable;
use VAKS\ListManager\Utility\PositionEvolutionComputer;
use VAKS\ListManager\Utility\ProductList;
use VAKS\VAKS;

class ListManagerPage
{
    public static function render(array $data)
    {
        $data = ObjectUtility::toObject($data);

        if (isset($_GET["edit"]))
            self::handleEdit($data);
        else if (isset($_GET["delete"]))
            self::handleDelete();
        else
            self::handleIndex($data);
    }

    public static function handleEdit(\StdClass $data)
    {
        $list = (!empty($_GET["edit"]))
            ? ListManager::getList($_GET["edit"])
            : null;

        if (isset($_POST["list"]))
        {
            $newList = new ProductList([
                "slug" => $_POST["list"]["slug"],
                "productIds" => $_POST["list"]["products"],
                "evolution" => (isset($list->evolution)) ? $list->evolution : null,
            ]);

            if ($_POST["list"]["recomputeEvolution"] && $list)
                $newList->evolution = PositionEvolutionComputer::compute($newList->productIds, $list->productIds);

            $oldSlug = $list ? $list->slug : null;

            ListManager::saveList($newList->slug, $newList, $oldSlug);

            wp_redirect(add_query_arg("edit", $newList->slug));
            exit;
        }

        $data->products = ($list)
            ? (new VAKSAPI())->getGames($list->productIds)
            : [];

        wp_enqueue_script("vaks-product-list", plugins_url("../Assets/js/ProductList.js", __FILE__));
        wp_localize_script("vaks-product-list", "vaksTrans", array(
            "apiUrl" => VAKS::instance()->config->get("apiUrl"),
        ));

        wp_enqueue_script("jquery-ui-sortable");

        wp_enqueue_script("select2", "https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/js/select2.min.js", array("jquery"), null, true);
        wp_enqueue_style("select2", "https://cdn.jsdelivr.net/npm/select2@4.0.13/dist/css/select2.min.css");

        $data->list = $list;

        require __DIR__ . "/template/lists_edit.php";
    }

    public static function handleDelete()
    {
        ListManager::deleteList($_GET["delete"]);

        wp_redirect(remove_query_arg("delete"));
        exit;
    }

    public static function handleIndex(\StdClass $data)
    {
        $data->table = new ListTable();
        $data->table->prepare_items();

        require __DIR__ . "/template/lists_index.php";
    }
}
