<?php
namespace VAKS\ListManager\Utility;

use VAKS\Common\Utility\ListManager;
use VAKS\Common\Utility\VAKSAPI;

if (!class_exists( "WP_List_Table"))
    require_once ABSPATH ."wp-admin/includes/class-wp-list-table.php";

class ListTable extends \WP_List_Table
{
    const FILTER_ITEM_ACTIONS = "vaks_filter_list_actions";

    protected $products = [];

    public function __construct()
    {
        parent::__construct([
            "singular" => "List",
            "plural" => "Lists",
            "ajax" => false,
        ]);
    }

    public function prepare_items()
    {
        $this->items = ListManager::getLists();

        $columns = $this->get_columns();
        $this->set_pagination_args([
            "total_items" => count($this->items),
            "per_page" => count($this->items),
        ]);
        $this->_column_headers = [$columns, [], []];

        $this->loadGames($this->items);
    }

    public function get_columns() {
        return [
            "slug" => __("Slug", "allkeyshop-widget"),
            "products" => __("Games", "allkeyshop-widget"),
        ];
    }

    public function column_default($item, $columnName)
    {
        switch ($columnName) {
            default:
                return print_r($item, true);
        }
    }

    public function column_slug($item)
    {
        $label = '<a href="'. add_query_arg("edit", $item->slug) .'">'. $item->slug .'</a>';
        $actions = [
            "edit" => '<a href="'. add_query_arg("edit", $item->slug) .'">'. __("Edit", "allkeyshop-widget") .'</a>',
            "delete" => '<a href="'. add_query_arg("delete", $item->slug) .'">'. __("Delete", "allkeyshop-widget") .'</a>',
        ];

        $actions = apply_filters(self::FILTER_ITEM_ACTIONS, $actions, $item);

        return sprintf("%s %s", $label, $this->row_actions($actions));
    }

    public function column_products($item)
    {
        $output = array_map(function ($gameId) {
            return (isset($this->products[$gameId]))
                ? "<li>". $this->products[$gameId]->name ." (ID: ". $this->products[$gameId]->id .")</li>"
                : "<li>ID: ". $gameId ."</li>";
        }, $item->productIds);

        return "<ol style=\"margin-top: 0\">". implode("", $output) ."</ol>";
    }

    public function loadGames(array $items)
    {
        $ids = [];

        foreach ($items as $item)
        {
            foreach ($item->productIds as $id)
                $ids[$id] = true;
        }

        $products = (new VAKSAPI())->getGames(array_keys($ids));

        if (is_iterable($products))
        {
            foreach ($products as $product)
                $this->products[$product->id] = $product;
        }
    }
}