<?php
namespace VAKS\PostScanner\Ajax;
use VAKS\PostScanner\Utility\GameExtractor;
use VAKS\VAKS;

class ScanPostsAjax
{
    public static function bind()
    {
        if (is_admin())
            add_action("wp_ajax_vaks_scan_posts", [self::class, "execute"]);
    }

    public static function execute()
    {
        check_ajax_referer("vaksPostScanner");

        $log = array();
        $postTypes = (!empty($_GET["postTypes"]))
            ? $_GET["postTypes"]
            : null;

        if (!$postTypes)
            exit;

        $batchSize = (!empty($_GET["batchSize"]))
            ? max(1, $_GET["batchSize"])
            : 1;

        $page = (!empty($_GET["page"]))
            ? max(0, $_GET["page"])
            : 0;

        $posts = self::getPosts($postTypes, $batchSize, $page);

        foreach ($posts as $post)
        {
            $suggestions = GameExtractor::getGamesFromPost($post);
            $games = (count($suggestions) > 0)
                ? array($suggestions[0])
                : array();
            $status = (count($games) > 0)
                ? "success"
                : "failure";
            $log[] = self::getLogArray($status, $post, $games);
        }

        echo json_encode(array(
            "posts" => $log
        ));
        exit;
    }

    private static function getLogArray($status, \WP_Post $post, $games)
    {
        return array(
            "status" => $status,
            "post" => array(
                "postType" => $post->post_type,
                "id" => $post->ID,
                "title" => $post->post_title,
                "editUrl" => admin_url() ."post.php?post=$post->ID&action=edit",
            ),
            "games" => $games,
        );
    }

    public static function getPosts($postType, $count, $page)
    {
        $modeMeta = VAKS::instance()->config->get("metaKeys.mode");

        $posts = get_posts(array(
            "post_type" => $postType,
            "meta_query" => array(
                array(
                    "key" => $modeMeta,
                    "compare" => "NOT EXISTS",
                ),
            ),
            "posts_per_page" => $count,
            "offset" => $page * $count,
            "orderby" => "date",
            "order" => "DESC",
        ));

        return $posts;
    }
}
