(function (VAKS) {
    if (!VAKS.PostScanner)
        VAKS.PostScanner = {};

    var $ = jQuery;

    VAKS.PostScanner.Post = function ($template, data, deletePost)
    {
        this.$template = $template;
        this.data = data;
        this.$container;
        this.ui = {};

        this.deletePost = deletePost;

        this.showEditForm = this.showEditForm.bind(this);
        this.deletePost = this.deletePost.bind(this);
        this.saveAndHideEditForm = this.saveAndHideEditForm.bind(this);
        this.hideEditForm = this.hideEditForm.bind(this);
    };

    VAKS.PostScanner.Post.prototype = {
        render: function ()
        {
            this.$container = this.$template
                .clone()
                .removeClass("hide");

            this.updateUiVars();

            this.ui.$status.text(this.data.status);
            this.ui.$postType.text(this.data.post.postType);
            this.ui.$postId.text(this.data.post.id);
            this.ui.$postTitle
                .text(this.data.post.title)
                .attr("href", this.data.post.editUrl);

            var gameNames = this.data.games.reduce(function (acc, game) {
                if (acc)
                    acc += ", ";

                return acc + game.name;
            }, "");

            this.ui.$gameName.text(gameNames);

            this.ui.$editBtn.click(this.showEditForm);
            this.ui.$deleteBtn.click(this.deletePost);
            this.ui.$saveBtn.click(this.saveAndHideEditForm);
            this.ui.$cancelBtn.click(this.hideEditForm);

            this.ui.$saveBtn.hide();
            this.ui.$cancelBtn.hide();

            return this.$container;
        },

        updateUiVars: function ()
        {
            var $els = this.$container.find("[data-tpl]");
            var self = this;

            $els.each(function () {
                var $this = $(this);
                var key = "$"+ $this.data("tpl");
                self.ui[key] = $this;
            });
        },

        showEditForm: function (e)
        {
            e.preventDefault();

            this.ui.$editBtn.hide();
            this.ui.$deleteBtn.hide();
            this.ui.$saveBtn.show();
            this.ui.$cancelBtn.show();

            var $select = $("<select></select>")
                .attr("multiple", "multiple");

            this.data.games.forEach(function (game) {
                var $option = $("<option></option>")
                    .attr("selected", "selected")
                    .attr("value", game.id)
                    .text(game.name);

                $select.append($option);
            });

            this.$container.find("[data-tpl='gameName']")
                .empty()
                .append($select);

            $select.select2({
                placeholder: VAKSTrans.searchPlaceholder,
                width: "100%",
                minimumInputLength: 3,
                multiple: true,
                ajax: {
                    delay: 300,
                    url: VAKSTrans.apiUrl +"vaks.php",
                    data: function (params) {
                        return {
                            action: "products",
                            currency: "eur",
                            search: params.term,
                        };
                    },
                    dataType: "json",
                    processResults: function (data) {
                        var items = [];

                        data.products.forEach(function (product) {
                            items.push({
                                text: product.name,
                                id: product.id,
                            });
                        });

                        return {
                            results: items,
                        };
                    },
                },
            })
        },

        hideEditForm: function (e)
        {
            e.preventDefault();

            this.ui.$editBtn.show();
            this.ui.$deleteBtn.show();
            this.ui.$saveBtn.hide();
            this.ui.$cancelBtn.hide();

            var $oldContainer = this.$container;
            this.render();
            $oldContainer.replaceWith(this.$container);
        },

        saveAndHideEditForm: function (e)
        {
            e.preventDefault();

            var $options = this.$container.find("select option:selected");
            var games = [];

            $options.each(function () {
                games.push({
                    id: this.value,
                    name: this.innerText,
                });
            });

            this.data.games = games;

            this.hideEditForm(e);
        },

        remove: function ()
        {
            this.$container.remove();
        },
    };
})(window.VAKS = window.VAKS || {});