(function (VAKS) {
    if (!VAKS.PostScanner)
        VAKS.PostScanner = {};

    var $ = jQuery;

    VAKS.PostScanner.Scanner = function ()
    {
        this.$saveBtn = $("[data-vaks-scanner-save]");
        this.form = new VAKS.PostScanner.Form();
        this.$submit = this.form.$form.find("[data-vaks-submit]");
        this.$log = $("#vaksScannerLog");
        this.$loading = $("[data-vaks-loading]");
        this.isScanning = false;
        this.batchSize = 5;
        this.page = 0;
        this.$message = $("[data-vaks-scanner-message]");

        var $tpl = this.$log.find("[data-log-tpl]");
        this.posts = new VAKS.PostScanner.Posts(this, this.$log, $tpl);

        this.onScanFinished = this.onScanFinished.bind(this);

        this.init();
    };

    VAKS.PostScanner.Scanner.prototype = {
        init: function ()
        {
            document.addEventListener("vaksScannerFormSubmit", this.onFormSubmit.bind(this));
            this.$saveBtn.click(this.posts.savePosts);
        },

        reset: function ()
        {
            this.page = 0;
        },

        onFormSubmit: function (e)
        {
            if (this.isScanning)
                this.stopScan();
            else
            {
                this.isScanning = true;

                if (!this.currentQuery)
                    this.scan(e.detail.postTypes, this.batchSize, this.page);

                this.$submit.addClass("running");
            }
        },

        stopScan: function ()
        {
            this.$submit.removeClass("running");
            this.isScanning = false;
        },

        scan: function (postTypes, batchSize, page)
        {
            if (!this.isScanning)
                return ;

            this.$message.text("");

            this.showLoading();

            var self = this;

            this.currentQuery = $.get({
                url: ajaxurl,
                data: {
                    action: "vaks_scan_posts",
                    postTypes: postTypes,
                    batchSize: batchSize,
                    page: page,
                    _wpnonce : VAKSTrans.nonce,
                },
                dataType: "json",
            })
                .then(function (response) {
                    ++self.page;
                    self.onScanFinished(response);

                    if (response.posts.length > 0)
                        self.scan(postTypes, batchSize, self.page);
                    else
                        self.stopScan();
                })
                .always(function () {
                    self.currentQuery = null;
                });
        },

        onScanFinished: function (response, rerunScan)
        {
            this.hideLoading();

            this.posts.addPosts(response.posts);
        },

        showLoading: function ()
        {
            this.$loading.removeClass("hide");
        },

        hideLoading: function ()
        {
            this.$loading.addClass("hide");
        },
    };
})(window.VAKS = window.VAKS || {});

jQuery(function ($) {
    new VAKS.PostScanner.Scanner();
});