<?php
namespace VAKS\PostScanner\Utility;
use VAKS\Common\Utility\VAKSAPI;

class GameExtractor
{
    const REGEX_MAX_LENGTH = 1000;

    public static function getGamesFromPost(\WP_Post $post)
    {
        $text = self::sanitize(($post->post_title . " " . $post->post_content));
        $results = self::getGamesFromText($text);

        return $results;
    }

    public static function getGamesFromText($text)
    {
        $text = " $text ";
        $games = (new VAKSAPI)->getAllGameNames();

        list($games, $patterns) = self::sanitizeGamesAndMakePatterns($games);
        $results = self::searchForMatches($text, $patterns);
        $results = self::computeResults($results, $games);

        return $results;
    }

    private static function sanitize($text)
    {
        $text = strip_tags($text);
        $text = str_replace("'", "", $text);
        $text = preg_replace("~[^\pL\d]+~u", " ", $text);
        $text = iconv("utf-8", "us-ascii//TRANSLIT", $text);
        $text = preg_replace("~[^ \w]+~", "", $text);
        $text = trim($text, " ");
        $text = preg_replace("~ +~", " ", $text);
        $text = strtolower($text);

        return $text;
    }

    private static function searchForMatches($text, array $patterns)
    {
        $results = [];

        foreach ($patterns as $pattern)
        {
            preg_match_all("#\W($pattern)\W#", $text, $matches);

            if (isset($matches[1]) && count($matches[1]) > 0)
                $results += $matches[1];
        }

        return $results;
    }

    private static function computeResults(array $results, array $games)
    {
        $output = [];

        foreach ($results as $result)
        {
            if (!isset($output[$result]))
                $output[$result] = $games[$result];

            ++$output[$result]["occurences"];
        }

        usort($output, function ($a, $b) {
            return $a["occurences"] < $b["occurences"];
        });

        return $output;
    }

    private static function sanitizeGamesAndMakePatterns(array $games)
    {
        $sanitizedGames = [];
        $sanitizedNames = [];

        foreach ($games as $game)
        {
            $sanitizedName = self::sanitize($game->name);
            $sanitizedGames[$sanitizedName] = (array)$game + ["occurences" => 0];
            $sanitizedNames[] = $sanitizedName;
        }

        $patterns = [""];
        $i = 0;

        // We sort them so "Borderlands 3" would be picked before "Borderlands"
        usort($sanitizedNames, function ($a, $b) {
            return strlen($b) - strlen($a);
        });

        foreach ($sanitizedNames as $name)
        {
            if (strlen($patterns[$i]) > self::REGEX_MAX_LENGTH)
            {
                ++$i;
                $patterns[$i] = "";
            }

            $pattern = &$patterns[$i];

            if (!empty($pattern))
                $pattern .= "|";

            $pattern .= $name;

        }

        return [
            $sanitizedGames,
            $patterns,
        ];
    }
}