(function (VAKS) {

    var $ = jQuery;

    VAKS.PresetManager = function (shortcodeGen, presets)
    {
        this.ui = {
            $loading: $("#vaksShortcodePresetsContainer"),
            $presetSelect: $("[data-vaks-presets]"),
            $overwriteBtn: $("[data-vaks-preset-overwrite]"),
            $createBtn: $("[data-vaks-preset-create]"),
            $deleteBtn: $("[data-vaks-preset-delete]"),
        };

        this.shortcodeGen = shortcodeGen;
        this.presets = presets || {};
        this.selectedPreset = null;
        this.presetUpdated = function () {};

        this.onPresetChanged = this.onPresetChanged.bind(this);
        this.loadCurrentPreset = this.loadCurrentPreset.bind(this);
        this.overwriteCurrentPreset = this.overwriteCurrentPreset.bind(this);
        this.createPreset = this.createPreset.bind(this);
        this.deleteCurrentPreset = this.deleteCurrentPreset.bind(this);

        this.init();
    };

    VAKS.PresetManager.prototype = {
        init: function ()
        {
            this.ui.$presetSelect.change(this.onPresetChanged);
            this.ui.$overwriteBtn.click(this.overwriteCurrentPreset);
            this.ui.$createBtn.click(this.createPreset);
            this.ui.$deleteBtn.click(this.deleteCurrentPreset);

            this.selectedPreset = this.ui.$presetSelect.val() || null;

            this.refreshUI();
            this.onPresetChanged();
        },

        onPresetChanged: function ()
        {
            this.selectedPreset = this.ui.$presetSelect.val();
            this.loadCurrentPreset();
            this.refreshUI();
        },

        loadCurrentPreset: function ()
        {
            if (this.selectedPreset === null)
                return ;

            this.shortcodeGen.loadWidgetConfig(this.presets[this.selectedPreset]);
        },

        updatePreset: function (presetName, config)
        {
            var self = this;

            this.showLoading();

            $.post({
                url: ajaxurl,
                data: {
                    action: "vaks_preset_update",
                    preset: {
                        name: presetName,
                        config: config,
                    },
                    _wpnonce: vaksTrans.nonce,
                },
            })
                .then(function (response) {
                    if (response === "ok")
                    {
                        // A preset can only extend 'default'.
                        config.preset = "default";
                        config.target = "";
                        self.presets[presetName] = config;
                        self.selectedPreset = presetName;
                        self.refreshUI();

                        self.presetUpdated(presetName, config);
                    }
                    else
                        console.error("Error while updating the preset: "+ response);
                })
                .fail(function (response) {
                    console.error("Error while updating the preset: "+ response.statusText);
                })
                .always(function () {
                    self.hideLoading();
                });
        },

        overwriteCurrentPreset: function (e)
        {
            if (e)
                e.preventDefault();

            if (this.selectedPreset === null)
                return ;

            var config = this.shortcodeGen.getWidgetConfig().config;
            this.updatePreset(this.selectedPreset, config);
        },

        createPreset: function (e)
        {
            if (e)
                e.preventDefault();

            var name = prompt(vaksTrans.enterPresetName);

            if (name)
            {
                var config = this.shortcodeGen.getWidgetConfig().config;
                this.updatePreset(name, config);
            }
        },

        deleteCurrentPreset: function (e)
        {
            var self = this;

            this.showLoading();

            $.post({
                url: ajaxurl,
                data: {
                    action: "vaks_preset_delete",
                    preset: this.selectedPreset,
                    _wpnonce: vaksTrans.nonce,
                },
            })
                .then(function (response) {
                    if (response === "ok")
                    {
                        delete self.presets[self.selectedPreset];
                        self.refreshUI();
                        self.selectedPreset = self.ui.$presetSelect.val();
                    }
                    else
                        console.error("Error while deleting the preset: "+ response);
                })
                .fail(function (response) {
                    console.error("Error while deleting the preset: "+ response.statusText);
                })
                .always(function () {
                    self.hideLoading();
                });
        },

        refreshUI: function ()
        {
            this.updateSelect();
            this.updateButtons();
        },

        updateSelect: function ()
        {
            var self = this;
            var appendOption = function (name, value, selected) {
                var $option = $("<option></option>")
                    .text(name)
                    .val(value)
                    .attr("selected", selected);

                self.ui.$presetSelect.append($option);
            };

            this.ui.$presetSelect.empty();

            for (var name in this.presets)
                appendOption(name, name, (name === this.selectedPreset));
        },

        updateButtons: function ()
        {
            this.ui.$overwriteBtn.attr("disabled", (this.selectedPreset === null));
            this.ui.$deleteBtn.attr("disabled", this.selectedPreset === vaksTrans.defaultPresetName || (this.selectedPreset === null));
        },

        showLoading: function ()
        {
            this.ui.$loading.css("display", "flex");
        },

        hideLoading: function ()
        {
            this.ui.$loading.hide();
        },
    };
})(window.VAKS = window.VAKS || {});