(function (VAKS) {

    var $ = jQuery;

    VAKS.ShortcodeGenerator = function ()
    {
        this.$form = $("#shortcodeGeneratorForm");
        this.$textarea = $("#shortcodeGeneratorResult");
        this.$clipboardBtn = $("[data-role='copyShortcode']");
        this.widgetContainer = $("[data-role='widget-preview']");
        this.widgetForm = new VAKS.WidgetForm(this.$form);
        this.preview = new VAKS.Preview(this.widgetContainer);
        this.presetManager = new VAKS.PresetManager(this, vaksTrans.presets);
        this.presetManager.presetUpdated = this.onPresetUpdated.bind(this);
        this.prevShortcode = "";

        this.onFormChange = this.onFormChange.bind(this);
        this.onFormSubmit = this.onFormSubmit.bind(this);
        this.copyShortcode = this.copyShortcode.bind(this);

        this.init();
    };

    VAKS.ShortcodeGenerator.prototype = {
        init: function ()
        {
            var self = this;

            this.$form
                .on("change", ":input", this.onFormChange)
                .on("keydown", ":input", function () { setTimeout(self.onFormChange) })
                .submit(this.onFormSubmit);

            this.$clipboardBtn.click(this.copyShortcode);

            this.onFormChange();
        },

        onFormSubmit: function (e)
        {
            e.preventDefault();
            this.onFormChange();
        },

        appendFieldError: function ($field, message)
        {
            var $error = $("<span></span>")
                .text(message)
                .addClass("vaks-error");

            $field.after($error[0]);
        },

        loadWidgetConfig: function (config)
        {
            var form = this.$form[0];

            for (var key in config)
            {
                var $field = $(form[key]);

                if ($field.attr("type") === "checkbox")
                    $field.attr("checked", !!config[key]);
                else
                    $field.val(config[key]);
            }

            var self = this;

            var func = function (prefix, config) {
                self.$form.find("[name^="+ prefix +"]").attr("checked", false);

                var fields = config.split(",").filter((el) => !!el);

                fields.forEach(function (field) {
                    var $field = $(form[prefix + field[0].toUpperCase() + field.slice(1)]);
                    $field.attr("checked", true);
                });
            };

            func("offerExcludedField", config.offerExcludedFields);
            func("tab", config.tabs);

            this.widgetForm.updateUI();
        },

        getWidgetConfig: function ()
        {
            var params = {};
            var data = this.$form.serializeArray();
            var error = false;
            var tabs = "";
            var offerExcludedFields = "";
            var self = this;

            this.appendCheckboxData(data, "showVouchers");
            this.appendCheckboxData(data, "autoHeight");
            this.appendCheckboxData(data, "openAksOnClick");
            this.appendCheckboxData(data, "openAksInNewTab");
            this.appendCheckboxData(data, "showOfficialPrice");
            this.appendCheckboxData(data, "showPlatforms");

            data.forEach(function (row)
            {
                if (row.name.indexOf("tab") === 0)
                {
                    if (tabs)
                        tabs += ",";

                    var name = row.name.substr(3);
                    tabs += name[0].toLowerCase() + name.substr(1);
                }
                else if (row.name.indexOf("offerExcludedField") === 0)
                {
                    if (offerExcludedFields)
                        offerExcludedFields += ",";

                    var name = row.name.substr(18);
                    offerExcludedFields += name[0].toLowerCase() + name.substr(1);
                }
                else
                {
                    if (typeof row.value === "string" && row.value.indexOf('"') !== -1)
                    {
                        error = true;
                        var $el = (self.$form[0].elements[row.name]);
                        self.appendFieldError($el, vaksTrans.doubleQuoteError);
                    }

                    params[row.name] = row.value;
                }
            });

            params["tabs"] = tabs;
            params["offerExcludedFields"] = offerExcludedFields;

            return {
                error: error,
                config: params,
            };
        },

        removeDefaultsFromConfig: function (config)
        {
            var reference = (config.preset && this.presetManager.presets[config.preset])
                ? this.presetManager.presets[config.preset]
                : vaksTrans.defaults;

            for (var key in config)
            {
                if (config[key] === reference[key])
                    delete config[key];
            }
        },

        onFormChange: function ()
        {
            this.$form.find(".vaks-error").remove();
            var result = this.getWidgetConfig();
            this.removeDefaultsFromConfig(result.config);

            if (!result.error)
            {
                var shortcode = this.generateShortcode(result.config);

                if (shortcode !== this.prevShortcode)
                {
                    this.$textarea.val(shortcode);
                    this.updateWidget(shortcode);
                    this.prevShortcode = shortcode;
                }
            }
            else
                this.$textarea.val(vaksTrans.error);
        },

        appendCheckboxData: function (data, fieldName)
        {
            var field = this.getFieldFromData(data, fieldName);

            if (field === null)
            {
                data.push({
                    name: fieldName,
                    value: 0,
                });
            }
            else
                field.value = 1;
        },

        getFieldFromData: function (data, fieldName)
        {
            var field = null;

            data.forEach(function (row)
            {
                if (row.name === fieldName)
                {
                    field = row;
                    return false;
                }

                return true;
            });

            return field;
        },

        generateShortcode: function (params)
        {
            var shortcode = "[aks_widget";

            for (var name in params)
                shortcode += " " + VAKS.Utility.camelCaseToSnakeCase(name) + "=\"" + params[name] + "\"";

            shortcode += "]";

            return shortcode;
        },

        showClipboardSuccess: function ()
        {
            $("[data-clipboard-success]").remove();

            var $success = $('<span class="vaks-shortcode-generator-clipboard-success" data-clipboard-success>' + vaksTrans.clipboardSuccess + '</span>');

            this.$clipboardBtn
                .after($success);

            setTimeout(function ()
            {
                $success.fadeOut(200, function () {
                    $success.remove();
                });
            }, 2000);
        },

        copyShortcode: function ()
        {
            this.$textarea.select();

            try
            {
                var successful = document.execCommand("copy");

                if (successful)
                    this.showClipboardSuccess();
                else
                    throw new Exception();
            } catch (e)
            {
                alert(vaksTrans.copyToClipboardNotSupported)
            }
        },

        updateWidget: function (shortcode)
        {
            this.preview.triggerReload(shortcode);
        },

        onPresetUpdated: function (presetName, parameters)
        {
            this.onFormChange();
        }
    };
})(window.VAKS = window.VAKS || {});

jQuery(function ($) {
    new VAKS.ShortcodeGenerator();
});