<?php
namespace VAKS\ShortcodeGenerator\Page;
use VAKS\Common\Utility\ObjectUtility;
use VAKS\Common\Utility\ParameterManager;
use VAKS\Common\Utility\ParameterSanitizer;
use VAKS\Common\Utility\PresetManager;
use VAKS\Common\Utility\ThemeManager;
use VAKS\Common\Utility\WidgetFormData;
use VAKS\VAKS;

class ShortcodeGeneratorPage
{
    public static function render(array $data)
    {
        \VAKS\enqueueVAKSWidgetManager();

        $defaults = ParameterManager::getDefaultValues();
        $presetName = VAKS::instance()->config->get("defaultPresetName");
        $preset = PresetManager::getPreset($presetName);

        if ($preset)
            $defaults = shortcode_atts($defaults, $preset);

        $data += WidgetFormData::getFormData(
            function ($fieldName) use ($defaults) {
                return (isset($defaults[$fieldName]))
                    ? $defaults[$fieldName]
                    : null;
            },
            function ($fieldName) {
                return $fieldName;
            },
            function ($fieldName) {
                return $fieldName;
            }
        );

        // Used in the template - do not remove
        $data = ObjectUtility::toObject($data);

        // We set a target so the user doesn't see a blank widget
        $data->form->target->value = 281;

        wp_enqueue_script("vaks-widget-preview", VAKS_ROOT_URL ."Common/Assets/js/WidgetPreview.js");
        wp_enqueue_script("vaks-shortcode-generator", VAKS_ROOT_URL ."ShortcodeGenerator/Assets/js/ShortcodeGenerator.js");
        wp_enqueue_script("vaks-shortcode-generator-utility", VAKS_ROOT_URL ."ShortcodeGenerator/Assets/js/Utility.js");
        wp_enqueue_script("vaks-shortcode-generator-preview", VAKS_ROOT_URL ."ShortcodeGenerator/Assets/js/Preview.js");
        wp_enqueue_script("vaks-shortcode-generator-preset-manager", VAKS_ROOT_URL ."ShortcodeGenerator/Assets/js/PresetManager.js");
        wp_enqueue_script("vaks-widget-form", VAKS_ROOT_URL ."Common/Assets/js/WidgetForm.js");


        wp_localize_script("vaks-shortcode-generator", "vaksTrans", array(
            "defaults" => $defaults,
            "error" => __("Error", "allkeyshop-widget"),
            "doubleQuoteError" => __("This value cannot contain the '\"' (double quote) character.", "allkeyshop-widget"),
            "copyToClipboardNotSupported" => __("This feature is not supported by your navigator.", "allkeyshop-widget"),
            "clipboardSuccess" => __("Copied!", "allkeyshop-widget"),
            "enterPresetName" =>__("Please enter a name for the new preset:", "allkeyshop-widget"),
            "extendingPresetIssue" => __("Warning: A preset can only extend the 'default' preset.\nThis means that the 'preset' parameter, which currently is '__currentPresetName__', will be reset to 'default'.\n\nClick continue to remove the 'preset' parameter and save the preset.\nClick cancel to cancel the save.", "allkeyshop-widget"),
            "loading" => __("Loading...", "allkeyshop-widget"),
            "nonce" => wp_create_nonce("vaksShortcodeGen"),
            "presets" => (object)PresetManager::getPresets(), // We cast to object to ensure it is not serialized as a JS Array if empty
            "defaultPresetName" => VAKS::instance()->config->get("defaultPresetName"),
            "themeCssUrl" => ThemeManager::getThemeUrl("__THEME_NAME__"),
        ));

        require __DIR__ . "/template/shortcode_generator.php";
    }
}
