(function (VAKS) {
    var $ = jQuery;

    VAKS.ThemeManagerForm = function ()
    {
        this.ui = {
            $form: $("[data-theme-settings]"),
        };

        this.onSettingsChanged = function () {};
        this.timer = null;

        this.onFormChange = this.onFormChange.bind(this);
        this.onFormSubmit = this.onFormSubmit.bind(this);

        this.init();
    };

    VAKS.ThemeManagerForm.prototype = {
        init: function ()
        {
            var self = this;

            this.bindColorPicker();

            this.ui.$form
                .on("change", ":input", this.onFormChange)
                .on("keydown", ":input", function () { setTimeout(self.onFormChange) })
                .submit(this.onFormSubmit);

            this.onFormChange();
        },

        bindColorPicker: function ()
        {
            var self = this;

            this.ui.$form.find("[data-vaks-colorpicker]").each(function () {
                var $this = $(this);
                var name = $this.data("vaksColorpicker");
                var $field = $("[data-vaks-param='"+ name +"']");
                var $preview = $("[data-vaks-color-preview='"+ name +"']");

                $preview.css("backgroundColor", $field.val());

                $this.colpick({
                    onChange: function (hue, hex, rgb, input) {
                        $preview.css("backgroundColor", "#"+ hex);
                        $field.val("#"+ hex);
                        self.onFormChange();
                    },
                    onBeforeShow: function () {
                        $this.colpickSetColor($field.val());
                    },
                });
            });
        },

        onFormSubmit: function (e)
        {
            e.preventDefault();
            this.onFormChange();
        },

        loadSettings: function (settings)
        {
            var form = this.ui.$form[0];

            for (var key in settings)
            {
                var $field = $(form[key]);
                $field.val(settings[key]);
            }

            this.updateColorPreviews();
        },

        getSettings: function ()
        {
            var data = this.ui.$form.serializeArray();
            var settings = data.reduce(function (output, row) {
                output[row.name] = row.value;

                return output;
            }, {});

            return settings;
        },

        updateColorPreviews: function ()
        {
            var self = this;

            setTimeout(function () {
                self.ui.$form.find("[data-vaks-colorpicker]").each(function () {
                    var $this = $(this);
                    var name = $this.data("vaksColorpicker");
                    var $field = $("[data-vaks-param='"+ name +"']");
                    var $preview = $("[data-vaks-color-preview='"+ name +"']");

                    $preview.css("backgroundColor", $field.val());
                });
            });
        },

        onFormChange: function ()
        {
            var settings = this.getSettings();
            this.onSettingsChanged(settings);
            this.updateColorPreviews();
        },
    };
})(window.VAKS = window.VAKS || {});