<?php
/*
Plugin Name: Allkeyshop Widget
Plugin URI: https://widget.allkeyshop.com
Description: Allkeyshop Widget integration for WordPress
Author: Allkeyshop.com
Version: 0.24.1
*/

namespace VAKS;
use ConfigManager\ConfigManager;
use VAKS\Common\AdminNotice\AdminNotice;
use VAKS\Common\Extension\PostTargetExtension;
use VAKS\Common\Page\WidgetAdminPage;
use VAKS\Common\Widget\VAKSWidget;
use VAKS\Common\Shortcode\VAKSShortcode;
use VAKS\Common\WordPress\InjectWidgetIntoPost;
use VAKS\Common\WordPress\MetaBox\PostGame;
use VAKS\Common\WordPress\OnPostSave;
use VAKS\Common\WordPress\Activation;
use VAKS\ListManager\Extension\ListEvolutionExtension;
use VAKS\Upgrade\UpgradeManager;
use VAKS\ShortcodeGenerator\Ajax\PresetAjax;
use VAKS\ShortcodeGenerator\Ajax\ShortcodePreviewAjax;
use VAKS\PostScanner\Ajax\SavePostGames;
use VAKS\PostScanner\Ajax\ScanPostsAjax;
use VAKS\ThemeManager\Ajax\ThemeAjax;
use VAKS\ThemeManager\Ajax\ThemePreviewAjax;
use VAKS\ThemeManager\WordPress\GenerateThemeCSS;

require_once __DIR__."/vendor/autoload.php";

define("VAKS_VERSION", "0.24.1");
define("VAKS_ROOT_DIR", __DIR__."/");
define("VAKS_ROOT_URL", plugins_url("/", __FILE__));

$upgrade = new UpgradeManager();

if (!$upgrade->isUpToDate(VAKS_VERSION))
    $upgrade->upgradeToVersion(VAKS_VERSION);

require_once __DIR__."/publicApi.php";

class VAKS
{
    private static $instance;

    public $config;

    public static function instance()
    {
        if (!self::$instance)
            self::$instance = new self();

        return self::$instance;
    }

    public function __construct()
    {
        $this->config = new ConfigManager(VAKS_ROOT_DIR."/Common/config/config.json", false);
        $this->config->mergeConfig($this->getCustomConfig());

        Activation::bind(__FILE__);

        AdminNotice::bind();

        PostTargetExtension::bind();
        OnPostSave::bind();
        InjectWidgetIntoPost::bind();
        PostGame::bind();
        ScanPostsAjax::bind();
        SavePostGames::bind();

        VAKSWidget::bind();
        VAKSShortcode::bind();
        WidgetAdminPage::bind();

        $this->bindPluginListLink();
        $this->bindTranslation();

        ShortcodePreviewAjax::bind();
        PresetAjax::bind();
        ThemePreviewAjax::bind();
        ThemeAjax::bind();

        GenerateThemeCSS::bind();

        ListEvolutionExtension::bind();
    }

    private function bindTranslation()
    {
        add_action("plugins_loaded", function () {
            load_plugin_textdomain("allkeyshop-widget", false, basename(dirname(__FILE__)) ."/Common/languages");
        });
    }

    private function bindPluginListLink()
    {
        $plugin = plugin_basename(__FILE__);

        add_filter("plugin_action_links_$plugin", function ($links) {
            $link = '<a href="tools.php?page=allkeyshop_widget">'. __("Settings") .'</a>';
            array_unshift($links, $link);
            return $links;
        });
    }

    private function getCustomConfig()
    {
        return get_option($this->config->get("metaKeys.customConfig"), array());
    }
}

VAKS::instance();